package com.ruoyi.system.service.impl;


import com.ruoyi.system.domain.StoreInfo;
import com.ruoyi.system.mapper.StoreInfoMapper;
import com.ruoyi.system.service.IStoreInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * 库位信息，记录周装货架存放库位信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-07-05
 */
@Service
public class StoreInfoServiceImpl implements IStoreInfoService
{
    @Autowired
    private StoreInfoMapper storeInfoMapper;

    /**
     * 查询库位信息，记录周装货架存放库位信息
     * 
     * @param id 库位信息，记录周装货架存放库位信息主键
     * @return 库位信息，记录周装货架存放库位信息
     */
    @Override
    public StoreInfo selectStoreInfoById(Long id)
    {
        return storeInfoMapper.selectStoreInfoById(id);
    }

    /**
     * 查询库位信息，记录周装货架存放库位信息列表
     * 
     * @param storeInfo 库位信息，记录周装货架存放库位信息
     * @return 库位信息，记录周装货架存放库位信息
     */
    @Override
    public List<StoreInfo> selectStoreInfoList(StoreInfo storeInfo)
    {
        return storeInfoMapper.selectStoreInfoList(storeInfo);
    }

    /**
     * 新增库位信息，记录周装货架存放库位信息
     * 
     * @param storeInfo 库位信息，记录周装货架存放库位信息
     * @return 结果
     */
    @Override
    public int insertStoreInfo(StoreInfo storeInfo)
    {
        return storeInfoMapper.insertStoreInfo(storeInfo);
    }

    /**
     * 修改库位信息，记录周装货架存放库位信息
     * 
     * @param storeInfo 库位信息，记录周装货架存放库位信息
     * @return 结果
     */
    @Override
    public int updateStoreInfo(StoreInfo storeInfo)
    {
        return storeInfoMapper.updateStoreInfo(storeInfo);
    }

    /**
     * 批量删除库位信息，记录周装货架存放库位信息
     * 
     * @param ids 需要删除的库位信息，记录周装货架存放库位信息主键
     * @return 结果
     */
    @Override
    public int deleteStoreInfoByIds(Long[] ids)
    {
        return storeInfoMapper.deleteStoreInfoByIds(ids);
    }

    /**
     * 删除库位信息，记录周装货架存放库位信息信息
     * 
     * @param id 库位信息，记录周装货架存放库位信息主键
     * @return 结果
     */
    @Override
    public int deleteStoreInfoById(Long id)
    {
        return storeInfoMapper.deleteStoreInfoById(id);
    }
}
